# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import data_source_rule_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2


class DataSourceRuleStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/create',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.CreateDataSourceRuleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/update',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.UpdateDataSourceRuleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
                )
        self.change_order = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/change_order',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.ChangeDataSourceRuleOrderRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/delete',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.GetDataSourceRuleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRulesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSourceRule/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class DataSourceRuleServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new DataSourceRule. When creating the resource, this method can apply two types of conditions: mapping projects where the cost incurred to the Cost, and mapping cloud service accounts to the Cost. By adjusting the `condition_policy` parameter, the DataSourceRule can be applied when all conditions are met, applied when any of the conditions are met, or always applied regardless of whether the conditions are met.
        request_example: >-
        {
        "name": "match_service_account_test",
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {"source": "account", "target": "data.project_id"}
        },
        "options": {"stop_processing": true},
        "tags": {"b": "c", "a": "b"},
        "data_source_id": "ds-c96609f5afeb"
        }
        response_example: >-
        {
        "data_source_rule_id": "rule-c8055231e212",
        "name": "match_service_account_test",
        "order": 2,
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {
        "a": "b",
        "b": "c"
        },
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:13:28.335Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific DataSourceRule. You can make changes in DataSourceRule settings, including filtering conditions. If the parameter `is_default` is `true`, only `Admin` type User can use this method.
        request_example: >-
        {
        "data_source_rule_id": "rule-c8055231e212",
        "name": "match_service_account_test",
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {"b": "c", "a": "b"}
        }
        response_example: >-
        {
        "data_source_rule_id": "rule-c8055231e212",
        "name": "match_service_account_test",
        "order": 2,
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {
        "a": "b",
        "b": "c"
        },
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:13:28.335Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def change_order(self, request, context):
        """
        desc: Changes the priority order of the DataSourceRules to apply. If there are multiple DataSourceRules applied in a specific service account, the priority order of the resources is requried. This method changes the priority order to apply DataSourceRules.
        request_example: >-
        {
        "data_source_rule_id": "rule-c8055231e212",
        "order": 2
        }
        response_example: >-
        {
        "data_source_rule_id": "rule-c8055231e212",
        "name": "match_service_account_test",
        "order": 2,
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {
        "a": "b",
        "b": "c"
        },
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:13:28.335Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific DataSourceRule. You must specify the `data_source_rule_id` of the DataSourceRule to delete. If the parameter `is_default` is `true`, only `Admin` type User can use this method.
        request_example: >-
        {
        "data_source_rule_id": "rule-22fab02f6b51"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific DataSourceRule. Prints detailed information about the DataSourceRule, including  `conditions_policy` and conditions applied to DataSources.
        request_example: >-
        {
        "data_source_rule_id": "rule-22fab02f6b51"
        }
        response_example: >-
        {
        "data_source_rule_id": "rule-22fab02f6b51",
        "name": "match_service_account",
        "order": 1,
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {},
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-25T16:01:51.858Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all DataSourceRules. You can use a query to get a filtered list of DataSourceRules.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "data_source_rule_id": "rule-22fab02f6b51",
        "name": "match_service_account",
        "order": 1,
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {},
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-25T16:01:51.858Z"
        },
        {
        "data_source_rule_id": "rule-188d366e9817",
        "name": "match_service_account",
        "order": 1,
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "tags": {},
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-03T16:00:54.099Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceRuleServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.CreateDataSourceRuleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.UpdateDataSourceRuleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.SerializeToString,
            ),
            'change_order': grpc.unary_unary_rpc_method_handler(
                    servicer.change_order,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.ChangeDataSourceRuleOrderRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.GetDataSourceRuleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRulesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.DataSourceRule', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSourceRule(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/create',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.CreateDataSourceRuleRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/update',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.UpdateDataSourceRuleRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def change_order(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/change_order',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.ChangeDataSourceRuleOrderRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/delete',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.GetDataSourceRuleRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRulesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSourceRule/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__rule__pb2.DataSourceRuleStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/domain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.core.v1 import handler_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_handler__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/identity/v1/domain.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a\"spaceone/api/core/v1/handler.proto\"\xae\x01\n\x13\x43reateDomainRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x0bplugin_info\x18\x02 \x01(\x0b\x32$.spaceone.api.identity.v1.PluginInfo\x12\'\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xb3\x01\n\x13UpdateDomainRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x39\n\x0bplugin_info\x18\x02 \x01(\x0b\x32$.spaceone.api.identity.v1.PluginInfo\x12\'\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"~\n\x11\x43hangeAuthRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x39\n\x0bplugin_info\x18\x02 \x01(\x0b\x32$.spaceone.api.identity.v1.PluginInfo\x12\x1b\n\x13release_auth_plugin\x18\x03 \x01(\x08\"\xe3\x01\n\x13UpdatePluginRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12O\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32\x39.spaceone.api.identity.v1.UpdatePluginRequest.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\"\n\rDomainRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\"3\n\x10GetDomainRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x0c\n\x04only\x18\x02 \x03(\t\"\xc4\x01\n\x0b\x44omainQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12:\n\x05state\x18\x04 \x01(\x0e\x32+.spaceone.api.identity.v1.DomainQuery.State\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xc9\x02\n\nDomainInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.spaceone.api.identity.v1.DomainInfo.State\x12\x39\n\x0bplugin_info\x18\x04 \x01(\x0b\x32$.spaceone.api.identity.v1.PluginInfo\x12\'\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\ndeleted_at\x18\x08 \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"Y\n\x0b\x44omainsInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.identity.v1.DomainInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"G\n\x0f\x44omainStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\"\xcd\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\tsecret_id\x18\x03 \x01(\t\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12)\n\x08metadata\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x46\n\x0cupgrade_mode\x18\x08 \x01(\x0e\x32\x30.spaceone.api.identity.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\x32\xc5\x0c\n\x06\x44omain\x12{\n\x06\x63reate\x12-.spaceone.api.identity.v1.CreateDomainRequest\x1a$.spaceone.api.identity.v1.DomainInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x14/identity/v1/domains\x12\x86\x01\n\x06update\x12-.spaceone.api.identity.v1.UpdateDomainRequest\x1a$.spaceone.api.identity.v1.DomainInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/identity/v1/domain/{domain_id}\x12\xa3\x01\n\x12\x63hange_auth_plugin\x12+.spaceone.api.identity.v1.ChangeAuthRequest\x1a$.spaceone.api.identity.v1.DomainInfo\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/identity/v1/domain/{domain_id}/change_auth_plugin\x12\x94\x01\n\rupdate_plugin\x12-.spaceone.api.identity.v1.UpdatePluginRequest\x1a$.spaceone.api.identity.v1.DomainInfo\".\x82\xd3\xe4\x93\x02(\x1a&/identity/v1/domain/{domain_id}/plugin\x12\x87\x01\n\rverify_plugin\x12\'.spaceone.api.identity.v1.DomainRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/\"-/identity/v1/domain/{domain_id}/plugin/verify\x12r\n\x06\x64\x65lete\x12\'.spaceone.api.identity.v1.DomainRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/identity/v1/domain/{domain_id}\x12\x80\x01\n\x06\x65nable\x12\'.spaceone.api.identity.v1.DomainRequest\x1a$.spaceone.api.identity.v1.DomainInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/identity/v1/domain/{domain_id}\x12\x81\x01\n\x07\x64isable\x12\'.spaceone.api.identity.v1.DomainRequest\x1a$.spaceone.api.identity.v1.DomainInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/identity/v1/domain/{domain_id}\x12\x80\x01\n\x03get\x12*.spaceone.api.identity.v1.GetDomainRequest\x1a$.spaceone.api.identity.v1.DomainInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/identity/v1/domain/{domain_id}\x12\x91\x01\n\x04list\x12%.spaceone.api.identity.v1.DomainQuery\x1a%.spaceone.api.identity.v1.DomainsInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x14/identity/v1/domainsZ\x1d\"\x1b/identity/v1/domains/search\x12m\n\x04stat\x12).spaceone.api.identity.v1.DomainStatQuery\x1a\x17.google.protobuf.Struct\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/identity/v1/domains/stat\x12m\n\x0eget_public_key\x12+.spaceone.api.core.v1.AuthenticationRequest\x1a,.spaceone.api.core.v1.AuthenticationResponse\"\x00\x62\x06proto3')



_CREATEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['CreateDomainRequest']
_UPDATEDOMAINREQUEST = DESCRIPTOR.message_types_by_name['UpdateDomainRequest']
_CHANGEAUTHREQUEST = DESCRIPTOR.message_types_by_name['ChangeAuthRequest']
_UPDATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdatePluginRequest']
_DOMAINREQUEST = DESCRIPTOR.message_types_by_name['DomainRequest']
_GETDOMAINREQUEST = DESCRIPTOR.message_types_by_name['GetDomainRequest']
_DOMAINQUERY = DESCRIPTOR.message_types_by_name['DomainQuery']
_DOMAININFO = DESCRIPTOR.message_types_by_name['DomainInfo']
_DOMAINSINFO = DESCRIPTOR.message_types_by_name['DomainsInfo']
_DOMAINSTATQUERY = DESCRIPTOR.message_types_by_name['DomainStatQuery']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_UPDATEPLUGINREQUEST_UPGRADEMODE = _UPDATEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_DOMAINQUERY_STATE = _DOMAINQUERY.enum_types_by_name['State']
_DOMAININFO_STATE = _DOMAININFO.enum_types_by_name['State']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
CreateDomainRequest = _reflection.GeneratedProtocolMessageType('CreateDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOMAINREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateDomainRequest)
  })
_sym_db.RegisterMessage(CreateDomainRequest)

UpdateDomainRequest = _reflection.GeneratedProtocolMessageType('UpdateDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOMAINREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateDomainRequest)
  })
_sym_db.RegisterMessage(UpdateDomainRequest)

ChangeAuthRequest = _reflection.GeneratedProtocolMessageType('ChangeAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEAUTHREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ChangeAuthRequest)
  })
_sym_db.RegisterMessage(ChangeAuthRequest)

UpdatePluginRequest = _reflection.GeneratedProtocolMessageType('UpdatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdatePluginRequest)
  })
_sym_db.RegisterMessage(UpdatePluginRequest)

DomainRequest = _reflection.GeneratedProtocolMessageType('DomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainRequest)
  })
_sym_db.RegisterMessage(DomainRequest)

GetDomainRequest = _reflection.GeneratedProtocolMessageType('GetDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetDomainRequest)
  })
_sym_db.RegisterMessage(GetDomainRequest)

DomainQuery = _reflection.GeneratedProtocolMessageType('DomainQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINQUERY,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainQuery)
  })
_sym_db.RegisterMessage(DomainQuery)

DomainInfo = _reflection.GeneratedProtocolMessageType('DomainInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAININFO,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainInfo)
  })
_sym_db.RegisterMessage(DomainInfo)

DomainsInfo = _reflection.GeneratedProtocolMessageType('DomainsInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINSINFO,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainsInfo)
  })
_sym_db.RegisterMessage(DomainsInfo)

DomainStatQuery = _reflection.GeneratedProtocolMessageType('DomainStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainStatQuery)
  })
_sym_db.RegisterMessage(DomainStatQuery)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.identity.v1.domain_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_DOMAIN = DESCRIPTOR.services_by_name['Domain']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAIN.methods_by_name['create']._options = None
  _DOMAIN.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\026\"\024/identity/v1/domains'
  _DOMAIN.methods_by_name['update']._options = None
  _DOMAIN.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/identity/v1/domain/{domain_id}'
  _DOMAIN.methods_by_name['change_auth_plugin']._options = None
  _DOMAIN.methods_by_name['change_auth_plugin']._serialized_options = b'\202\323\344\223\0024\0322/identity/v1/domain/{domain_id}/change_auth_plugin'
  _DOMAIN.methods_by_name['update_plugin']._options = None
  _DOMAIN.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\002(\032&/identity/v1/domain/{domain_id}/plugin'
  _DOMAIN.methods_by_name['verify_plugin']._options = None
  _DOMAIN.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\002/\"-/identity/v1/domain/{domain_id}/plugin/verify'
  _DOMAIN.methods_by_name['delete']._options = None
  _DOMAIN.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/identity/v1/domain/{domain_id}'
  _DOMAIN.methods_by_name['enable']._options = None
  _DOMAIN.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002!\032\037/identity/v1/domain/{domain_id}'
  _DOMAIN.methods_by_name['disable']._options = None
  _DOMAIN.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002!\032\037/identity/v1/domain/{domain_id}'
  _DOMAIN.methods_by_name['get']._options = None
  _DOMAIN.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/identity/v1/domain/{domain_id}'
  _DOMAIN.methods_by_name['list']._options = None
  _DOMAIN.methods_by_name['list']._serialized_options = b'\202\323\344\223\0025\022\024/identity/v1/domainsZ\035\"\033/identity/v1/domains/search'
  _DOMAIN.methods_by_name['stat']._options = None
  _DOMAIN.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\033\"\031/identity/v1/domains/stat'
  _CREATEDOMAINREQUEST._serialized_start=227
  _CREATEDOMAINREQUEST._serialized_end=401
  _UPDATEDOMAINREQUEST._serialized_start=404
  _UPDATEDOMAINREQUEST._serialized_end=583
  _CHANGEAUTHREQUEST._serialized_start=585
  _CHANGEAUTHREQUEST._serialized_end=711
  _UPDATEPLUGINREQUEST._serialized_start=714
  _UPDATEPLUGINREQUEST._serialized_end=941
  _UPDATEPLUGINREQUEST_UPGRADEMODE._serialized_start=896
  _UPDATEPLUGINREQUEST_UPGRADEMODE._serialized_end=941
  _DOMAINREQUEST._serialized_start=943
  _DOMAINREQUEST._serialized_end=977
  _GETDOMAINREQUEST._serialized_start=979
  _GETDOMAINREQUEST._serialized_end=1030
  _DOMAINQUERY._serialized_start=1033
  _DOMAINQUERY._serialized_end=1229
  _DOMAINQUERY_STATE._serialized_start=1185
  _DOMAINQUERY_STATE._serialized_end=1229
  _DOMAININFO._serialized_start=1232
  _DOMAININFO._serialized_end=1561
  _DOMAININFO_STATE._serialized_start=1185
  _DOMAININFO_STATE._serialized_end=1229
  _DOMAINSINFO._serialized_start=1563
  _DOMAINSINFO._serialized_end=1652
  _DOMAINSTATQUERY._serialized_start=1654
  _DOMAINSTATQUERY._serialized_end=1725
  _PLUGININFO._serialized_start=1728
  _PLUGININFO._serialized_end=2061
  _PLUGININFO_UPGRADEMODE._serialized_start=896
  _PLUGININFO_UPGRADEMODE._serialized_end=941
  _DOMAIN._serialized_start=2064
  _DOMAIN._serialized_end=3669
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import resource_group_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2


class ResourceGroupStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.inventory.v1.ResourceGroup/create',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.CreateResourceGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.inventory.v1.ResourceGroup/update',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.UpdateResourceGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.ResourceGroup/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.ResourceGroup/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.GetResourceGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.ResourceGroup/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.ResourceGroup/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class ResourceGroupServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new ResourceGroup. You can integrate `resource`s from different `provider`s by specifying the cloud resources to be grouped in the `resources` parameter.
        request_example: >-
        {
        "name": "azure-group-1",
        "resources": [
        {
        "resource_type": "inventory.Server?provider=azure&cloud_service_group=Compute&cloud_service_type=VirtualMachine",
        "filter": [
        {"o": "eq", "k": "provider", "v": "azure"},
        {"o": "eq", "k": "cloud_service_group", "v": "Compute"},
        {"o": "eq", "k": "cloud_service_type", "v": "VirtualMachine"}
        ]
        }
        ],
        "options": {
        "raw_filter": []
        },
        "tags": {
        "a": "b"
        }
        }
        response_example: >-
        {
        "resource_group_id": "rsc-grp-7d46a1fc7738",
        "name": "azure-group-1",
        "resources": [
        {
        "resource_type": "inventory.Server?provider=azure&cloud_service_group=Compute&cloud_service_type=VirtualMachine",
        "filter": [
        {
        "k": "provider",
        "v": "azure",
        "o": "eq"
        },
        {
        "k": "cloud_service_group",
        "v": "Compute",
        "o": "eq"
        },
        {
        "k": "cloud_service_type",
        "v": "VirtualMachine",
        "o": "eq"
        }
        ]
        }
        ],
        "options": {
        "raw_filter": []
        },
        "tags": {
        "a": "b"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-23T01:50:33.152Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific ResourceGroup. You can make changes in ResourceGroup settings, including `name`, `tags`, and grouped resources in the ResourceGroup.
        request_example: >-
        {
        "resource_group_id": "rsc-grp-7d46a1fc7738",
        "name": "azure-grp-test2",
        "resources": [
        {
        "resource_type": "inventory.Server?provider=azure&cloud_service_group=Compute&cloud_service_type=VirtualMachine",
        "filter": [
        {"k": "provider", "v": "azure", "o": "eq"},
        {"o": "eq", "k": "cloud_service_group", "v": "Compute"},
        {"v": "VirtualMachine", "k": "cloud_service_type", "o": "eq"}
        ]
        }
        ],
        "options": {},
        "tags": {
        "b": "c"
        }
        }
        response_example: >-
        {
        "resource_group_id": "rsc-grp-7d46a1fc7738",
        "name": "azure-grp-test2",
        "resources": [
        {
        "resource_type": "inventory.Server?provider=azure&cloud_service_group=Compute&cloud_service_type=VirtualMachine",
        "filter": [
        {
        "k": "provider",
        "v": "azure",
        "o": "eq"
        },
        {
        "k": "cloud_service_group",
        "v": "Compute",
        "o": "eq"
        },
        {
        "k": "cloud_service_type",
        "v": "VirtualMachine",
        "o": "eq"
        }
        ]
        }
        ],
        "options": {
        "raw_filter": []
        },
        "tags": {
        "a": "b"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-23T01:50:33.152Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific ResourceGroup. You must specify the `resource_group_id` of the ResourceGroup to delete.
        request_example: >-
        {
        "resource_group_id": "rsc-grp-aa3c4ca465b2"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific ResourceGroup. Prints detailed information about the ResourceGroup, including the information of the grouped cloud resources.
        request_example: >-
        {
        "resource_group_id": "rsc-grp-aa3c4ca465b2"
        }
        response_example: >-
        {
        "resource_group_id": "rsc-grp-aa3c4ca465b2",
        "name": "stset",
        "resources": [
        {
        "resource_type": "inventory.Server?provider=aws&cloud_service_group=EC2&cloud_service_type=Instance",
        "filter": [
        {
        "k": "provider",
        "o": "eq",
        "v": "aws"
        },
        {
        "v": "EC2",
        "k": "cloud_service_group",
        "o": "eq"
        },
        {
        "o": "eq",
        "k": "cloud_service_type",
        "v": "Instance"
        }
        ],
        "keyword": "test"
        }
        ],
        "options": {
        "raw_filter": []
        },
        "tags": {},
        "project_id": "project-18655561c535",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-01T10:23:20.537Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all ResourceGroups. You can use a query to get a filtered list of ResourceGroups.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "name",
        "value": [
        "azure-vmss-group",
        "stset"
        ],
        "operator": "in"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [
        {
        "resource_group_id": "rsc-grp-4c86e071e0f0",
        "name": "azure-vmss-group",
        "resources": [
        {
        "resource_type": "inventory.CloudService?provider=azure&cloud_service_group=Compute&cloud_service_type=VmScaleSet",
        "filter": [
        {
        "k": "provider",
        "v": "azure",
        "o": "eq"
        },
        {
        "v": "Compute",
        "k": "cloud_service_group",
        "o": "eq"
        },
        {
        "k": "cloud_service_type",
        "v": "VmScaleSet",
        "o": "eq"
        }
        ]
        }
        ],
        "options": {
        "raw_filter": []
        },
        "tags": {},
        "project_id": "project-9074eea97d7e",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-04-23T03:23:40.037Z"
        },
        {
        "resource_group_id": "rsc-grp-aa3c4ca465b2",
        "name": "stset",
        "resources": [
        {
        "resource_type": "inventory.Server?provider=aws&cloud_service_group=EC2&cloud_service_type=Instance",
        "filter": [
        {
        "k": "provider",
        "v": "aws",
        "o": "eq"
        },
        {
        "v": "EC2",
        "k": "cloud_service_group",
        "o": "eq"
        },
        {
        "k": "cloud_service_type",
        "v": "Instance",
        "o": "eq"
        }
        ],
        "keyword": "test"
        }
        ],
        "options": {
        "raw_filter": [
        [
        "test"
        ]
        ]
        },
        "tags": {},
        "project_id": "project-18655561c535",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-01T10:23:20.537Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResourceGroupServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.CreateResourceGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.UpdateResourceGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.GetResourceGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.ResourceGroup', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ResourceGroup(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.ResourceGroup/create',
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.CreateResourceGroupRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.ResourceGroup/update',
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.UpdateResourceGroupRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.ResourceGroup/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.ResourceGroup/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.GetResourceGroupRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.ResourceGroup/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.ResourceGroup/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_resource__group__pb2.ResourceGroupStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/note.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/monitoring/v1/note.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"F\n\x11\x43reateNoteRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x0c\n\x04note\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"E\n\x11UpdateNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x0c\n\x04note\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"1\n\x0bNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x95\x01\n\tNoteQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07note_id\x18\x02 \x01(\t\x12\x10\n\x08\x61lert_id\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x8a\x01\n\x08NoteInfo\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x10\n\x08\x61lert_id\x18\x02 \x01(\t\x12\x0c\n\x04note\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"W\n\tNotesInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.monitoring.v1.NoteInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rNoteStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xff\x05\n\x04Note\x12{\n\x06\x63reate\x12-.spaceone.api.monitoring.v1.CreateNoteRequest\x1a$.spaceone.api.monitoring.v1.NoteInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x14/monitoring/v1/notes\x12\x84\x01\n\x06update\x12-.spaceone.api.monitoring.v1.UpdateNoteRequest\x1a$.spaceone.api.monitoring.v1.NoteInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/monitoring/v1/note/{note_id}\x12p\n\x06\x64\x65lete\x12\'.spaceone.api.monitoring.v1.NoteRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/monitoring/v1/note/{note_id}\x12~\n\x03get\x12*.spaceone.api.monitoring.v1.GetNoteRequest\x1a$.spaceone.api.monitoring.v1.NoteInfo\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/monitoring/v1/note/{note_id}\x12\x91\x01\n\x04list\x12%.spaceone.api.monitoring.v1.NoteQuery\x1a%.spaceone.api.monitoring.v1.NotesInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x14/monitoring/v1/notesZ\x1d\"\x1b/monitoring/v1/notes/search\x12m\n\x04stat\x12).spaceone.api.monitoring.v1.NoteStatQuery\x1a\x17.google.protobuf.Struct\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/monitoring/v1/notes/statb\x06proto3')



_CREATENOTEREQUEST = DESCRIPTOR.message_types_by_name['CreateNoteRequest']
_UPDATENOTEREQUEST = DESCRIPTOR.message_types_by_name['UpdateNoteRequest']
_NOTEREQUEST = DESCRIPTOR.message_types_by_name['NoteRequest']
_GETNOTEREQUEST = DESCRIPTOR.message_types_by_name['GetNoteRequest']
_NOTEQUERY = DESCRIPTOR.message_types_by_name['NoteQuery']
_NOTEINFO = DESCRIPTOR.message_types_by_name['NoteInfo']
_NOTESINFO = DESCRIPTOR.message_types_by_name['NotesInfo']
_NOTESTATQUERY = DESCRIPTOR.message_types_by_name['NoteStatQuery']
CreateNoteRequest = _reflection.GeneratedProtocolMessageType('CreateNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateNoteRequest)
  })
_sym_db.RegisterMessage(CreateNoteRequest)

UpdateNoteRequest = _reflection.GeneratedProtocolMessageType('UpdateNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateNoteRequest)
  })
_sym_db.RegisterMessage(UpdateNoteRequest)

NoteRequest = _reflection.GeneratedProtocolMessageType('NoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteRequest)
  })
_sym_db.RegisterMessage(NoteRequest)

GetNoteRequest = _reflection.GeneratedProtocolMessageType('GetNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetNoteRequest)
  })
_sym_db.RegisterMessage(GetNoteRequest)

NoteQuery = _reflection.GeneratedProtocolMessageType('NoteQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTEQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteQuery)
  })
_sym_db.RegisterMessage(NoteQuery)

NoteInfo = _reflection.GeneratedProtocolMessageType('NoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTEINFO,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteInfo)
  })
_sym_db.RegisterMessage(NoteInfo)

NotesInfo = _reflection.GeneratedProtocolMessageType('NotesInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTESINFO,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NotesInfo)
  })
_sym_db.RegisterMessage(NotesInfo)

NoteStatQuery = _reflection.GeneratedProtocolMessageType('NoteStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTESTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteStatQuery)
  })
_sym_db.RegisterMessage(NoteStatQuery)

_NOTE = DESCRIPTOR.services_by_name['Note']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTE.methods_by_name['create']._options = None
  _NOTE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\026\"\024/monitoring/v1/notes'
  _NOTE.methods_by_name['update']._options = None
  _NOTE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\037\032\035/monitoring/v1/note/{note_id}'
  _NOTE.methods_by_name['delete']._options = None
  _NOTE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\037*\035/monitoring/v1/note/{note_id}'
  _NOTE.methods_by_name['get']._options = None
  _NOTE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\037\022\035/monitoring/v1/note/{note_id}'
  _NOTE.methods_by_name['list']._options = None
  _NOTE.methods_by_name['list']._serialized_options = b'\202\323\344\223\0025\022\024/monitoring/v1/notesZ\035\"\033/monitoring/v1/notes/search'
  _NOTE.methods_by_name['stat']._options = None
  _NOTE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\033\"\031/monitoring/v1/notes/stat'
  _CREATENOTEREQUEST._serialized_start=192
  _CREATENOTEREQUEST._serialized_end=262
  _UPDATENOTEREQUEST._serialized_start=264
  _UPDATENOTEREQUEST._serialized_end=333
  _NOTEREQUEST._serialized_start=335
  _NOTEREQUEST._serialized_end=384
  _GETNOTEREQUEST._serialized_start=386
  _GETNOTEREQUEST._serialized_end=452
  _NOTEQUERY._serialized_start=455
  _NOTEQUERY._serialized_end=604
  _NOTEINFO._serialized_start=607
  _NOTEINFO._serialized_end=745
  _NOTESINFO._serialized_start=747
  _NOTESINFO._serialized_end=834
  _NOTESTATQUERY._serialized_start=836
  _NOTESTATQUERY._serialized_end=924
  _NOTE._serialized_start=927
  _NOTE._serialized_end=1694
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/note.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$spaceone/api/inventory/v1/note.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"G\n\x11\x43reateNoteRequest\x12\x11\n\trecord_id\x18\x01 \x01(\t\x12\x0c\n\x04note\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"E\n\x11UpdateNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x0c\n\x04note\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"1\n\x0bNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x9c\x01\n\tNoteQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07note_id\x18\x02 \x01(\t\x12\x11\n\trecord_id\x18\x03 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x91\x01\n\x08NoteInfo\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x03 \x01(\t\x12\x0c\n\x04note\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"V\n\tNotesInfo\x12\x34\n\x07results\x18\x01 \x03(\x0b\x32#.spaceone.api.inventory.v1.NoteInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rNoteStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xee\x05\n\x04Note\x12x\n\x06\x63reate\x12,.spaceone.api.inventory.v1.CreateNoteRequest\x1a#.spaceone.api.inventory.v1.NoteInfo\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/inventory/v1/notes\x12\x81\x01\n\x06update\x12,.spaceone.api.inventory.v1.UpdateNoteRequest\x1a#.spaceone.api.inventory.v1.NoteInfo\"$\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/inventory/v1/note/{note_id}\x12n\n\x06\x64\x65lete\x12&.spaceone.api.inventory.v1.NoteRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/inventory/v1/note/{note_id}\x12{\n\x03get\x12).spaceone.api.inventory.v1.GetNoteRequest\x1a#.spaceone.api.inventory.v1.NoteInfo\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/inventory/v1/note/{note_id}\x12\x8d\x01\n\x04list\x12$.spaceone.api.inventory.v1.NoteQuery\x1a$.spaceone.api.inventory.v1.NotesInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x13/inventory/v1/notesZ\x1c\"\x1a/inventory/v1/notes/search\x12k\n\x04stat\x12(.spaceone.api.inventory.v1.NoteStatQuery\x1a\x17.google.protobuf.Struct\" \x82\xd3\xe4\x93\x02\x1a\"\x18/inventory/v1/notes/statb\x06proto3')



_CREATENOTEREQUEST = DESCRIPTOR.message_types_by_name['CreateNoteRequest']
_UPDATENOTEREQUEST = DESCRIPTOR.message_types_by_name['UpdateNoteRequest']
_NOTEREQUEST = DESCRIPTOR.message_types_by_name['NoteRequest']
_GETNOTEREQUEST = DESCRIPTOR.message_types_by_name['GetNoteRequest']
_NOTEQUERY = DESCRIPTOR.message_types_by_name['NoteQuery']
_NOTEINFO = DESCRIPTOR.message_types_by_name['NoteInfo']
_NOTESINFO = DESCRIPTOR.message_types_by_name['NotesInfo']
_NOTESTATQUERY = DESCRIPTOR.message_types_by_name['NoteStatQuery']
CreateNoteRequest = _reflection.GeneratedProtocolMessageType('CreateNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateNoteRequest)
  })
_sym_db.RegisterMessage(CreateNoteRequest)

UpdateNoteRequest = _reflection.GeneratedProtocolMessageType('UpdateNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateNoteRequest)
  })
_sym_db.RegisterMessage(UpdateNoteRequest)

NoteRequest = _reflection.GeneratedProtocolMessageType('NoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.NoteRequest)
  })
_sym_db.RegisterMessage(NoteRequest)

GetNoteRequest = _reflection.GeneratedProtocolMessageType('GetNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetNoteRequest)
  })
_sym_db.RegisterMessage(GetNoteRequest)

NoteQuery = _reflection.GeneratedProtocolMessageType('NoteQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.NoteQuery)
  })
_sym_db.RegisterMessage(NoteQuery)

NoteInfo = _reflection.GeneratedProtocolMessageType('NoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTEINFO,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.NoteInfo)
  })
_sym_db.RegisterMessage(NoteInfo)

NotesInfo = _reflection.GeneratedProtocolMessageType('NotesInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTESINFO,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.NotesInfo)
  })
_sym_db.RegisterMessage(NotesInfo)

NoteStatQuery = _reflection.GeneratedProtocolMessageType('NoteStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.NoteStatQuery)
  })
_sym_db.RegisterMessage(NoteStatQuery)

_NOTE = DESCRIPTOR.services_by_name['Note']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTE.methods_by_name['create']._options = None
  _NOTE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\025\"\023/inventory/v1/notes'
  _NOTE.methods_by_name['update']._options = None
  _NOTE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\036\032\034/inventory/v1/note/{note_id}'
  _NOTE.methods_by_name['delete']._options = None
  _NOTE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\036*\034/inventory/v1/note/{note_id}'
  _NOTE.methods_by_name['get']._options = None
  _NOTE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\036\022\034/inventory/v1/note/{note_id}'
  _NOTE.methods_by_name['list']._options = None
  _NOTE.methods_by_name['list']._serialized_options = b'\202\323\344\223\0023\022\023/inventory/v1/notesZ\034\"\032/inventory/v1/notes/search'
  _NOTE.methods_by_name['stat']._options = None
  _NOTE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\032\"\030/inventory/v1/notes/stat'
  _CREATENOTEREQUEST._serialized_start=190
  _CREATENOTEREQUEST._serialized_end=261
  _UPDATENOTEREQUEST._serialized_start=263
  _UPDATENOTEREQUEST._serialized_end=332
  _NOTEREQUEST._serialized_start=334
  _NOTEREQUEST._serialized_end=383
  _GETNOTEREQUEST._serialized_start=385
  _GETNOTEREQUEST._serialized_end=451
  _NOTEQUERY._serialized_start=454
  _NOTEQUERY._serialized_end=610
  _NOTEINFO._serialized_start=613
  _NOTEINFO._serialized_end=758
  _NOTESINFO._serialized_start=760
  _NOTESINFO._serialized_end=846
  _NOTESTATQUERY._serialized_start=848
  _NOTESTATQUERY._serialized_end=936
  _NOTE._serialized_start=939
  _NOTE._serialized_end=1689
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource_tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/provisioning/v1/resource_tag.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"Q\n\x10ResourceTagQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xa1\x01\n\x18\x43reateResourceTagRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x02 \x01(\t\x12\x1a\n\x12resource_tag_value\x18\x03 \x03(\t\x12\x15\n\rresource_type\x18\x04 \x03(\t\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\xba\x01\n\x18UpdateResourceTagRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fresource_tag_id\x18\x02 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x03 \x01(\t\x12\x1a\n\x12resource_tag_value\x18\x04 \x03(\t\x12\x15\n\rresource_type\x18\x05 \x03(\t\x12\x10\n\x08required\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\"l\n\x12ResourceTagRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fresource_tag_id\x18\x02 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\"_\n\x14ResourceTagStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xb1\x01\n\x0fResourceTagInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fresource_tag_id\x18\x02 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x03 \x01(\t\x12\x1a\n\x12resource_tag_value\x18\x04 \x03(\t\x12\x15\n\rresource_type\x18\x05 \x03(\t\x12\x10\n\x08required\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\"g\n\x10ResourceTagsInfo\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.spaceone.api.provisioning.v1.ResourceTagInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xeb\x07\n\x0bResourceTag\x12\xa3\x01\n\x13\x63reate_resource_tag\x12\x36.spaceone.api.provisioning.v1.CreateResourceTagRequest\x1a-.spaceone.api.provisioning.v1.ResourceTagInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/provisioning/v1/resource-tag\x12\xc4\x01\n\x11get_resource_tags\x12..spaceone.api.provisioning.v1.ResourceTagQuery\x1a..spaceone.api.provisioning.v1.ResourceTagsInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/provisioning/v1/resource-tagsZ\'\"%/provisioning/v1/resource-tags/search\x12\xac\x01\n\x10get_resource_tag\x12\x30.spaceone.api.provisioning.v1.ResourceTagRequest\x1a-.spaceone.api.provisioning.v1.ResourceTagInfo\"7\x82\xd3\xe4\x93\x02\x31\x12//provisioning/v1/resource-tag/{resource_tag_id}\x12\xa3\x01\n\x13update_resource_tag\x12\x36.spaceone.api.provisioning.v1.UpdateResourceTagRequest\x1a-.spaceone.api.provisioning.v1.ResourceTagInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/provisioning/v1/resource-tag\x12\x98\x01\n\x13\x64\x65lete_resource_tag\x12\x30.spaceone.api.provisioning.v1.ResourceTagRequest\x1a\x16.google.protobuf.Empty\"7\x82\xd3\xe4\x93\x02\x31*//provisioning/v1/resource-tag/{resource_tag_id}\x12\x7f\n\x04stat\x12\x32.spaceone.api.provisioning.v1.ResourceTagStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/provisioning/v1/resource-tag/statb\x06proto3')



_RESOURCETAGQUERY = DESCRIPTOR.message_types_by_name['ResourceTagQuery']
_CREATERESOURCETAGREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceTagRequest']
_UPDATERESOURCETAGREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceTagRequest']
_RESOURCETAGREQUEST = DESCRIPTOR.message_types_by_name['ResourceTagRequest']
_RESOURCETAGSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceTagStatQuery']
_RESOURCETAGINFO = DESCRIPTOR.message_types_by_name['ResourceTagInfo']
_RESOURCETAGSINFO = DESCRIPTOR.message_types_by_name['ResourceTagsInfo']
ResourceTagQuery = _reflection.GeneratedProtocolMessageType('ResourceTagQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagQuery)
  })
_sym_db.RegisterMessage(ResourceTagQuery)

CreateResourceTagRequest = _reflection.GeneratedProtocolMessageType('CreateResourceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCETAGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateResourceTagRequest)
  })
_sym_db.RegisterMessage(CreateResourceTagRequest)

UpdateResourceTagRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCETAGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateResourceTagRequest)
  })
_sym_db.RegisterMessage(UpdateResourceTagRequest)

ResourceTagRequest = _reflection.GeneratedProtocolMessageType('ResourceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagRequest)
  })
_sym_db.RegisterMessage(ResourceTagRequest)

ResourceTagStatQuery = _reflection.GeneratedProtocolMessageType('ResourceTagStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagStatQuery)
  })
_sym_db.RegisterMessage(ResourceTagStatQuery)

ResourceTagInfo = _reflection.GeneratedProtocolMessageType('ResourceTagInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagInfo)
  })
_sym_db.RegisterMessage(ResourceTagInfo)

ResourceTagsInfo = _reflection.GeneratedProtocolMessageType('ResourceTagsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagsInfo)
  })
_sym_db.RegisterMessage(ResourceTagsInfo)

_RESOURCETAG = DESCRIPTOR.services_by_name['ResourceTag']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCETAG.methods_by_name['create_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['create_resource_tag']._serialized_options = b'\202\323\344\223\002\037\"\035/provisioning/v1/resource-tag'
  _RESOURCETAG.methods_by_name['get_resource_tags']._options = None
  _RESOURCETAG.methods_by_name['get_resource_tags']._serialized_options = b'\202\323\344\223\002I\022\036/provisioning/v1/resource-tagsZ\'\"%/provisioning/v1/resource-tags/search'
  _RESOURCETAG.methods_by_name['get_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['get_resource_tag']._serialized_options = b'\202\323\344\223\0021\022//provisioning/v1/resource-tag/{resource_tag_id}'
  _RESOURCETAG.methods_by_name['update_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['update_resource_tag']._serialized_options = b'\202\323\344\223\002\037\032\035/provisioning/v1/resource-tag'
  _RESOURCETAG.methods_by_name['delete_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['delete_resource_tag']._serialized_options = b'\202\323\344\223\0021*//provisioning/v1/resource-tag/{resource_tag_id}'
  _RESOURCETAG.methods_by_name['stat']._options = None
  _RESOURCETAG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/provisioning/v1/resource-tag/stat'
  _RESOURCETAGQUERY._serialized_start=204
  _RESOURCETAGQUERY._serialized_end=285
  _CREATERESOURCETAGREQUEST._serialized_start=288
  _CREATERESOURCETAGREQUEST._serialized_end=449
  _UPDATERESOURCETAGREQUEST._serialized_start=452
  _UPDATERESOURCETAGREQUEST._serialized_end=638
  _RESOURCETAGREQUEST._serialized_start=640
  _RESOURCETAGREQUEST._serialized_end=748
  _RESOURCETAGSTATQUERY._serialized_start=750
  _RESOURCETAGSTATQUERY._serialized_end=845
  _RESOURCETAGINFO._serialized_start=848
  _RESOURCETAGINFO._serialized_end=1025
  _RESOURCETAGSINFO._serialized_start=1027
  _RESOURCETAGSINFO._serialized_end=1130
  _RESOURCETAG._serialized_start=1133
  _RESOURCETAG._serialized_end=2136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/region.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/inventory/v1/region.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x84\x01\n\x13\x43reateRegionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bregion_code\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"p\n\x13UpdateRegionRequest\x12\x11\n\tregion_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"5\n\rRegionRequest\x12\x11\n\tregion_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x10GetRegionRequest\x12\x11\n\tregion_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa8\x01\n\x0bRegionQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tregion_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nregion_key\x18\x04 \x01(\t\x12\x13\n\x0bregion_code\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xca\x01\n\nRegionInfo\x12\x11\n\tregion_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nregion_key\x18\x03 \x01(\t\x12\x13\n\x0bregion_code\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\"Z\n\x0bRegionsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.inventory.v1.RegionInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0fRegionStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x99\x06\n\x06Region\x12~\n\x06\x63reate\x12..spaceone.api.inventory.v1.CreateRegionRequest\x1a%.spaceone.api.inventory.v1.RegionInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/inventory/v1/regions\x12\x89\x01\n\x06update\x12..spaceone.api.inventory.v1.UpdateRegionRequest\x1a%.spaceone.api.inventory.v1.RegionInfo\"(\x82\xd3\xe4\x93\x02\"\x1a /inventory/v1/region/{region_id}\x12t\n\x06\x64\x65lete\x12(.spaceone.api.inventory.v1.RegionRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"* /inventory/v1/region/{region_id}\x12\x83\x01\n\x03get\x12+.spaceone.api.inventory.v1.GetRegionRequest\x1a%.spaceone.api.inventory.v1.RegionInfo\"(\x82\xd3\xe4\x93\x02\"\x12 /inventory/v1/region/{region_id}\x12\x95\x01\n\x04list\x12&.spaceone.api.inventory.v1.RegionQuery\x1a&.spaceone.api.inventory.v1.RegionsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/inventory/v1/regionsZ\x1e\"\x1c/inventory/v1/regions/search\x12o\n\x04stat\x12*.spaceone.api.inventory.v1.RegionStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/inventory/v1/regions/statb\x06proto3')



_CREATEREGIONREQUEST = DESCRIPTOR.message_types_by_name['CreateRegionRequest']
_UPDATEREGIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateRegionRequest']
_REGIONREQUEST = DESCRIPTOR.message_types_by_name['RegionRequest']
_GETREGIONREQUEST = DESCRIPTOR.message_types_by_name['GetRegionRequest']
_REGIONQUERY = DESCRIPTOR.message_types_by_name['RegionQuery']
_REGIONINFO = DESCRIPTOR.message_types_by_name['RegionInfo']
_REGIONSINFO = DESCRIPTOR.message_types_by_name['RegionsInfo']
_REGIONSTATQUERY = DESCRIPTOR.message_types_by_name['RegionStatQuery']
CreateRegionRequest = _reflection.GeneratedProtocolMessageType('CreateRegionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREGIONREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateRegionRequest)
  })
_sym_db.RegisterMessage(CreateRegionRequest)

UpdateRegionRequest = _reflection.GeneratedProtocolMessageType('UpdateRegionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREGIONREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateRegionRequest)
  })
_sym_db.RegisterMessage(UpdateRegionRequest)

RegionRequest = _reflection.GeneratedProtocolMessageType('RegionRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGIONREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RegionRequest)
  })
_sym_db.RegisterMessage(RegionRequest)

GetRegionRequest = _reflection.GeneratedProtocolMessageType('GetRegionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREGIONREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetRegionRequest)
  })
_sym_db.RegisterMessage(GetRegionRequest)

RegionQuery = _reflection.GeneratedProtocolMessageType('RegionQuery', (_message.Message,), {
  'DESCRIPTOR' : _REGIONQUERY,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RegionQuery)
  })
_sym_db.RegisterMessage(RegionQuery)

RegionInfo = _reflection.GeneratedProtocolMessageType('RegionInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONINFO,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RegionInfo)
  })
_sym_db.RegisterMessage(RegionInfo)

RegionsInfo = _reflection.GeneratedProtocolMessageType('RegionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONSINFO,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RegionsInfo)
  })
_sym_db.RegisterMessage(RegionsInfo)

RegionStatQuery = _reflection.GeneratedProtocolMessageType('RegionStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _REGIONSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.region_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RegionStatQuery)
  })
_sym_db.RegisterMessage(RegionStatQuery)

_REGION = DESCRIPTOR.services_by_name['Region']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGION.methods_by_name['create']._options = None
  _REGION.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/inventory/v1/regions'
  _REGION.methods_by_name['update']._options = None
  _REGION.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\"\032 /inventory/v1/region/{region_id}'
  _REGION.methods_by_name['delete']._options = None
  _REGION.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\"* /inventory/v1/region/{region_id}'
  _REGION.methods_by_name['get']._options = None
  _REGION.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\022 /inventory/v1/region/{region_id}'
  _REGION.methods_by_name['list']._options = None
  _REGION.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/inventory/v1/regionsZ\036\"\034/inventory/v1/regions/search'
  _REGION.methods_by_name['stat']._options = None
  _REGION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/inventory/v1/regions/stat'
  _CREATEREGIONREQUEST._serialized_start=193
  _CREATEREGIONREQUEST._serialized_end=325
  _UPDATEREGIONREQUEST._serialized_start=327
  _UPDATEREGIONREQUEST._serialized_end=439
  _REGIONREQUEST._serialized_start=441
  _REGIONREQUEST._serialized_end=494
  _GETREGIONREQUEST._serialized_start=496
  _GETREGIONREQUEST._serialized_end=566
  _REGIONQUERY._serialized_start=569
  _REGIONQUERY._serialized_end=737
  _REGIONINFO._serialized_start=740
  _REGIONINFO._serialized_end=942
  _REGIONSINFO._serialized_start=944
  _REGIONSINFO._serialized_end=1034
  _REGIONSTATQUERY._serialized_start=1036
  _REGIONSTATQUERY._serialized_end=1126
  _REGION._serialized_start=1129
  _REGION._serialized_end=1922
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/plugin/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/monitoring/plugin/metric.proto\x12\x1espaceone.api.monitoring.plugin\x1a\x1cgoogle/protobuf/struct.proto\"\x9f\x01\n\rMetricRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05query\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x04 \x01(\t\"\xf4\x01\n\x11MetricDataRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0cmetric_query\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06metric\x18\x04 \x01(\t\x12\r\n\x05start\x18\x05 \x01(\t\x12\x0b\n\x03\x65nd\x18\x06 \x01(\t\x12\x0e\n\x06period\x18\x07 \x01(\x05\x12\x0c\n\x04stat\x18\x08 \x01(\t\x12\x0e\n\x06schema\x18\t \x01(\t\"\x8c\x01\n\nMetricInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12%\n\x04unit\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0cmetric_query\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"J\n\x0bMetricsInfo\x12;\n\x07metrics\x18\x01 \x03(\x0b\x32*.spaceone.api.monitoring.plugin.MetricInfo\"e\n\x0eMetricDataInfo\x12*\n\x06labels\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct2\xdf\x01\n\x06Metric\x12\x64\n\x04list\x12-.spaceone.api.monitoring.plugin.MetricRequest\x1a+.spaceone.api.monitoring.plugin.MetricsInfo\"\x00\x12o\n\x08get_data\x12\x31.spaceone.api.monitoring.plugin.MetricDataRequest\x1a..spaceone.api.monitoring.plugin.MetricDataInfo\"\x00\x62\x06proto3')



_METRICREQUEST = DESCRIPTOR.message_types_by_name['MetricRequest']
_METRICDATAREQUEST = DESCRIPTOR.message_types_by_name['MetricDataRequest']
_METRICINFO = DESCRIPTOR.message_types_by_name['MetricInfo']
_METRICSINFO = DESCRIPTOR.message_types_by_name['MetricsInfo']
_METRICDATAINFO = DESCRIPTOR.message_types_by_name['MetricDataInfo']
MetricRequest = _reflection.GeneratedProtocolMessageType('MetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.MetricRequest)
  })
_sym_db.RegisterMessage(MetricRequest)

MetricDataRequest = _reflection.GeneratedProtocolMessageType('MetricDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICDATAREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.MetricDataRequest)
  })
_sym_db.RegisterMessage(MetricDataRequest)

MetricInfo = _reflection.GeneratedProtocolMessageType('MetricInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICINFO,
  '__module__' : 'spaceone.api.monitoring.plugin.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.MetricInfo)
  })
_sym_db.RegisterMessage(MetricInfo)

MetricsInfo = _reflection.GeneratedProtocolMessageType('MetricsInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICSINFO,
  '__module__' : 'spaceone.api.monitoring.plugin.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.MetricsInfo)
  })
_sym_db.RegisterMessage(MetricsInfo)

MetricDataInfo = _reflection.GeneratedProtocolMessageType('MetricDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICDATAINFO,
  '__module__' : 'spaceone.api.monitoring.plugin.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.MetricDataInfo)
  })
_sym_db.RegisterMessage(MetricDataInfo)

_METRIC = DESCRIPTOR.services_by_name['Metric']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRICREQUEST._serialized_start=110
  _METRICREQUEST._serialized_end=269
  _METRICDATAREQUEST._serialized_start=272
  _METRICDATAREQUEST._serialized_end=516
  _METRICINFO._serialized_start=519
  _METRICINFO._serialized_end=659
  _METRICSINFO._serialized_start=661
  _METRICSINFO._serialized_end=735
  _METRICDATAINFO._serialized_start=737
  _METRICDATAINFO._serialized_end=838
  _METRIC._serialized_start=841
  _METRIC._serialized_end=1064
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.identity.v1 import project_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2


class ProjectStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/create',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/update',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.update_profit_margin = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/update_profit_margin',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/delete',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/get',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/list',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/stat',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.add_member = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/add_member',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.AddProjectMemberRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
                )
        self.modify_member = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/modify_member',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ModifyProjectMemberRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
                )
        self.remove_member = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/remove_member',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.RemoveProjectMemberRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.list_members = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/list_members',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectMemberQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingsInfo.FromString,
                )
        self.list_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/list_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
                )
        self.create_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/create_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.latest_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/latest_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.stat_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/stat_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.monthly_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/monthly_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
                )


class ProjectServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_profit_margin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_member(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def modify_member(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove_member(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_members(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def latest_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def monthly_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.CreateProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'update_profit_margin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_profit_margin,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.GetProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'add_member': grpc.unary_unary_rpc_method_handler(
                    servicer.add_member,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.AddProjectMemberRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.SerializeToString,
            ),
            'modify_member': grpc.unary_unary_rpc_method_handler(
                    servicer.modify_member,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ModifyProjectMemberRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.SerializeToString,
            ),
            'remove_member': grpc.unary_unary_rpc_method_handler(
                    servicer.remove_member,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.RemoveProjectMemberRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'list_members': grpc.unary_unary_rpc_method_handler(
                    servicer.list_members,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectMemberQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingsInfo.SerializeToString,
            ),
            'list_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.list_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.SerializeToString,
            ),
            'create_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.create_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'latest_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.latest_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'stat_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'monthly_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.monthly_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.identity.v1.Project', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Project(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/create',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.CreateProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/update',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_profit_margin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/update_profit_margin',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/delete',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/get',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.GetProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/list',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/stat',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add_member(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/add_member',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.AddProjectMemberRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def modify_member(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/modify_member',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ModifyProjectMemberRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def remove_member(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/remove_member',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.RemoveProjectMemberRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_members(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/list_members',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectMemberQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/list_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/create_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def latest_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/latest_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/stat_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def monthly_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/monthly_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
